# -*- coding: utf-8 -*-
#    This program computes and plots the cumulated distributions
#    of two popularity distributions : one for which exhaustive data
#    is known and provided in a file, the other which is assumed to
#    follow a Zipf's law whose parameter is given.
#
#    To obtain the graph of figure 3.2 of Sharing, one must run:
#    python figure3-2.py ML-ecoutes_et_telechargements_mlo_norm.csv 0.533332
#    where 0.533332 is the parameter of the best fitting Zipf's law
#    for the observed data in this example. It has been estimated by
#    running:
#    python fit3.py ML-ecoutes_et_telechargements_mlo_norm.csv
#
#    Copyright (C) 2011 - Philippe Aigrain
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.


from pylab import *
import csv

def power(x,a):
  return(x**(-a))

def main(argv):
  if len(argv) < 3:
    print ("Usage: %s <name of csv file for dist 1, zipf's parameter for law 2") % argv[0]
    print "Plots cumulated distributions for two popularity distributions"
    sys.exit(0)
  # Let's first compute the number of lines in the data file
  cr = csv.reader(open(argv[1],"rb"))
  N = 0
  for row in cr:
    N += 1
  print N
# Initializing stuff
  a2 = float(argv[2])
  ind = range(N)
  s1 = zeros(N,float)
  s2 = zeros(N,float)
  t1 = zeros(N,float)
  t2 = zeros(N,float)
# Reading data for dist 1
  cr = csv.reader(open(argv[1],"rb"))
  tot1 = 0.0
  i = 0
  for row in cr:
    s1[i] = 1.0*(int) (row[0])
    tot1 += s1[i]
    i += 1
  for i in range(N):
    s1[i] = s1[i] / tot1
# Computing dist2
  for i in range(N,0,-1):
      s2[i-1] = power(i,a2)
  tot2 = 0.0
  for i in range(N):
    tot2 += s2[i]
  for i in range(N):
    s2[i] = s2[i] / tot2
# Normalized cumulated
  for i in range(0,N,1):
      if i > 0:
        t1[i] = s1[i]+t1[i-1]
        t2[i] = s2[i]+t2[i-1]
      else:
        t1[i] = s1[i]
        t2[i] = s2[i]
  plotpar = {'axes.labelsize': 24,
               'text.fontsize': 24,
               'legend.fontsize': 20,
               'xtick.labelsize': 22,
               'ytick.labelsize': 22,
               'text.usetex': False}
  rcParams.update(plotpar)
  close(1)
  figure(num=1, figsize=(16,12), facecolor='w', edgecolor='k')
# Plotting
  (l1,l2) = plot(ind,t1,'k-',ind,t2,'k--',lw=2, antialiased=True)
# Replace by next line for a color figure
#  (l1,l2) = plot(ind,t1,'b-',ind,t2,'g--',lw=2, antialiased=True)
  xaxislabel= "popularity ranks"
  xlabel(xaxislabel)
  yaxislabel = "Cumulated popularity share"
  ylabel(yaxislabel)
  ylim(0.0, 1.0)
  legend( (l1,l2),  ('observed data','Best-fitting Zipf\'s law (parameter 0.533)'), loc='lower right')
  grid(True)
  savefig('illustration.png')
  show()
#  pylab.xlabel(r"bla $\alpha$") -> illustrating use of LaTeX in figure text

if __name__ == '__main__':
    main(sys.argv)
