# -*- coding: iso-8859-15 -*-
#    Share of wealth held by 20% wealthiest under a Pareto distribution
#    depending on its parameter. To generate figure A-1 of "Sharing",
#    one has to run
#    python figureA-1.py
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA

from pylab import *

def main():
# S defines the sampling for k, N the size of the population
# Conventionally, the minimum wealth is set to 1.0
  S = 1000
  N = 20000
  # vector for parameter k
  t = arange(0.5,1.5,1.0/S)
  # vector for results
  s = zeros(S,float)
  # vector for distribution
  dist = zeros(N, float)
  # vector for cumulated distribution for a given parameter k
  cum = zeros(N, float)
  n = 0
  for k in t:
    # loop on parameter
    tot = 0.0
    # Computing the distribution of wealth itself
    for j in range(N):
      dist[j] = j * k * ((j+1.0)**(-(k+1.0)))
      tot += dist[j]
    # Normalizing it
    for j in range(N):
      dist[j] = dist[j]/tot
    # computing the cumulated distribution
    cum[N-1] = dist[N-1]
    for j in arange(N-1,-1,-1):
      if j < N-1:
        cum[j] = cum[j+1] + dist[j]
    #  Amount of wealth held by richer 20%
    s[n] = 1.0 - cum[N/5]
    n += 1
  plotpar = {'axes.labelsize': 24,
               'text.fontsize': 24,
               'legend.fontsize': 20,
               'xtick.labelsize': 22,
               'ytick.labelsize': 22,
               'text.usetex': False}
  rcParams.update(plotpar)
  close(1)
  figure(num=1, figsize=(16,12), facecolor='w', edgecolor='k')
# Plotting
  plot(t,s,'k-',lw=2)
# Replace by next line for a color figure
#  plot(t,s,lw=2)
  xlabel('parameter k')
  ylabel('Share of wealth held by 20% wealthiest')
  yticks((0.5,0.6,0.7,0.8,0.9,1.0),('0.5','0.6','0.7','0.8','0.9','1.0'))
  grid(True)
  savefig('illustration.png')
  show()

if __name__ == '__main__':
  main()
